@@ -31,6 +31,10 @@ class ITaskAddFormMenuTarget(Interface):
     """Task add form menu target marker interface"""
 
 
+class ITaskPropertiesTarget(Interface):
+    """Marker interface for task properties menus"""
+
+
 class ITaskActiveColumn(Interface):
     """Marker interface for 'active' tasks columns"""
 
